==> qlcplus_4.13.1.orig.tar.xz: qlcplus-QLC-_4.13.1/webaccess/src/webaccess_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="171"/>
        <source>Loading project...</source>
        <translation>Caricamento progetto...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="207"/>
        <source>Fixture stored and loaded</source>
        <translation>Fixture salvata e caricata</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="407"/>
        <source>Username and password are required fields.</source>
        <translation>Nome utente e password sono parametri richiesti.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="413"/>
        <location filename="webaccess.cpp" line="438"/>
        <source>User level has to be a positive integer.</source>
        <translation>Il livello dell&apos;utente deve essere un intero positivo.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="432"/>
        <source>Username is required.</source>
        <translation>Il nome utente è richiesto.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="450"/>
        <source>Error while saving passwords file.</source>
        <translation>Errore durante il salvataggio del file delle password.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="465"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>La configurazione di rete è stata modificata. Riavviare per applicare le modifiche.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Autostart configuration changed</source>
        <translation>La configurazione di avvio è stata modificata</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="860"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Oggetto non ancora supportato via web</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="912"/>
        <location filename="webaccess.cpp" line="965"/>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1131"/>
        <source>Enable</source>
        <translation>Abilita</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1163"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1164"/>
        <source>Fade In</source>
        <translation>Fade In</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1165"/>
        <source>Fade Out</source>
        <translation>Fade Out</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1166"/>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1167"/>
        <source>Notes</source>
        <translation>Note</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1463"/>
        <source>Load project</source>
        <translation>Carica progetto</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1465"/>
        <source>Simple Desk</source>
        <translation>Banco Semplice</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1467"/>
        <source>Configuration</source>
        <translation>Configurazione</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Carica fixture</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Livello di accesso</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Lasciare in bianco per non modificare</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Solo Console Virtuale</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Console Virtuale e Banco Semplice</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Tutto</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Elimina utente</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Nuovo nome utente...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Nuova password...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>Nome utente e password sono parametri richiesti.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Aggiungi utente</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Nota: se nella lista non esiste almeno un utente con accesso a &quot;Tutto&quot;, l&apos;accesso autorizzato verrà disabilitato.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="323"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="332"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="340"/>
        <source>Universes configuration</source>
        <translation>Configurazione degli universi</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="347"/>
        <source>Audio configuration</source>
        <translation>Configurazione audio</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="355"/>
        <source>User loaded fixtures</source>
        <translation>Fixture caricate dall&apos;utente</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="364"/>
        <source>Authorized users</source>
        <translation>Utenti autorizzati</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="101"/>
        <source>Network interface: </source>
        <translation>Interfaccia di rete:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="106"/>
        <source>Access point name (SSID): </source>
        <translation>Nome dell&apos;access point (SSID):</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="108"/>
        <source>WPA-PSK Password: </source>
        <translation>Password WPA-PSK:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="113"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dinamico (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="115"/>
        <source>Static</source>
        <translation>Statico</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="119"/>
        <source>IP Address: </source>
        <translation>Indirizzo IP:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="121"/>
        <source>Netmask: </source>
        <translation>Maschera:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="123"/>
        <source>Gateway: </source>
        <translation>Gateway:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="126"/>
        <location filename="webaccessnetwork.cpp" line="344"/>
        <source>Apply changes</source>
        <translation>Applica le modifiche</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="327"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="333"/>
        <source>Network configuration</source>
        <translation>Configurazione di rete</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="338"/>
        <source>Project autostart</source>
        <translation>Progetto di avvio automatico</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>No project</source>
        <translation>Nessun progetto</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Use current project</source>
        <translation>Usa il progetto corrente</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="349"/>
        <source>Shutdown</source>
        <translation>Arresta</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Pagina successiva</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Reimposta universo</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.3.orig.tar.xz: qlcplus-QLC-_4.14.3/webaccess/src/webaccess_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>WebAccess</name>
    <message>
        <source>Loading project...</source>
        <translation>Caricamento progetto...</translation>
    </message>
    <message>
        <source>Fixture stored and loaded</source>
        <translation>Fixture salvata e caricata</translation>
    </message>
    <message>
        <source>Username and password are required fields.</source>
        <translation>Nome utente e password sono parametri richiesti.</translation>
    </message>
    <message>
        <source>User level has to be a positive integer.</source>
        <translation>Il livello dell&apos;utente deve essere un intero positivo.</translation>
    </message>
    <message>
        <source>Username is required.</source>
        <translation>Il nome utente è richiesto.</translation>
    </message>
    <message>
        <source>Error while saving passwords file.</source>
        <translation>Errore durante il salvataggio del file delle password.</translation>
    </message>
    <message>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>La configurazione di rete è stata modificata. Riavviare per applicare le modifiche.</translation>
    </message>
    <message>
        <source>Autostart configuration changed</source>
        <translation>La configurazione di avvio è stata modificata</translation>
    </message>
    <message>
        <source>Widget not supported (yet) for web access</source>
        <translation>Oggetto non ancora supportato via web</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Abilita</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>Fade In</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>Fade Out</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Load project</source>
        <translation>Carica progetto</translation>
    </message>
    <message>
        <source>Simple Desk</source>
        <translation>Banco Semplice</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Configurazione</translation>
    </message>
    <message>
        <source>An error occurred while updating the network configuration.</source>
        <translation>Si è verificato un errore durante l&apos;aggiornamento della configurazione di rete.</translation>
    </message>
    <message>
        <source>Wi-Fi hotspot successfully activated.</source>
        <translation>Hotspot Wi-Fi attivato correttamente.</translation>
    </message>
    <message>
        <source>An error occurred while creating a Wi-Fi hotspot.</source>
        <translation>Si è verificato un errore durante la creazione del hotspot Wi-Fi.</translation>
    </message>
    <message>
        <source>Wi-Fi hotspot successfully deactivated.</source>
        <translation>Hotspot Wi-Fi disattivato correttamente.</translation>
    </message>
    <message>
        <source>Color 2 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5 Reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <source>Load fixture</source>
        <translation>Carica fixture</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Access level</source>
        <translation>Livello di accesso</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <source>Leave blank to not change</source>
        <translation>Lasciare in bianco per non modificare</translation>
    </message>
    <message>
        <source>Only Virtual Console</source>
        <translation>Solo Console Virtuale</translation>
    </message>
    <message>
        <source>Virtual Console and Simple Desk</source>
        <translation>Console Virtuale e Banco Semplice</translation>
    </message>
    <message>
        <source>Everything</source>
        <translation>Tutto</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Delete user</source>
        <translation>Elimina utente</translation>
    </message>
    <message>
        <source>New username...</source>
        <translation>Nuovo nome utente...</translation>
    </message>
    <message>
        <source>New password...</source>
        <translation>Nuova password...</translation>
    </message>
    <message>
        <source>Username and password are required fields.</source>
        <translation>Nome utente e password sono parametri richiesti.</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Aggiungi utente</translation>
    </message>
    <message>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Nota: se nella lista non esiste almeno un utente con accesso a &quot;Tutto&quot;, l&apos;accesso autorizzato verrà disabilitato.</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Universes configuration</source>
        <translation>Configurazione degli universi</translation>
    </message>
    <message>
        <source>Audio configuration</source>
        <translation>Configurazione audio</translation>
    </message>
    <message>
        <source>User loaded fixtures</source>
        <translation>Fixture caricate dall&apos;utente</translation>
    </message>
    <message>
        <source>Authorized users</source>
        <translation>Utenti autorizzati</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <source>Access point name (SSID): </source>
        <translation>Nome dell&apos;access point (SSID):</translation>
    </message>
    <message>
        <source>WPA-PSK Password: </source>
        <translation>Password WPA-PSK:</translation>
    </message>
    <message>
        <source>Dynamic (DHCP)</source>
        <translation>Dinamico (DHCP)</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statico</translation>
    </message>
    <message>
        <source>IP Address: </source>
        <translation>Indirizzo IP:</translation>
    </message>
    <message>
        <source>Netmask: </source>
        <translation>Maschera:</translation>
    </message>
    <message>
        <source>Gateway: </source>
        <translation>Gateway:</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>Applica le modifiche</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Network configuration</source>
        <translation>Configurazione di rete</translation>
    </message>
    <message>
        <source>Project autostart</source>
        <translation>Progetto di avvio automatico</translation>
    </message>
    <message>
        <source>No project</source>
        <translation>Nessun progetto</translation>
    </message>
    <message>
        <source>Use current project</source>
        <translation>Usa il progetto corrente</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Arresta</translation>
    </message>
    <message>
        <source>Wi-Fi Hotspot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished">Abilita</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network interface</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Pagina successiva</translation>
    </message>
    <message>
        <source>Reset universe</source>
        <translation>Reimposta universo</translation>
    </message>
    <message>
        <source>Universe</source>
        <translation>Universo</translation>
    </message>
</context>
</TS>
